@@ -2,7 +2,7 @@
 PlexLibrary
 """
 import urllib
-from plexapi import video
+from plexapi import video, utils
 from plexapi.exceptions import NotFound
 
 
@@ -47,10 +47,19 @@ class Library(object):
     def get(self, title):
         return video.find_item(self.server, '/library/all', title)
 
-    def search(self, title, videotype=None, filter='all'):
-        title = urllib.quote(title)
-        query = '/library/%s?title=%s' % (filter, title)
-        if videotype: query += '&type=%d' % video.search_type(videotype)
+    def search(self, title, filter='all', vtype=None, **tags):
+        """ Search all available content.
+            title: Title to search (pass None to search all titles).
+            filter: One of {'all', 'onDeck', 'recentlyAdded'}.
+            videotype: One of {'movie', 'show', 'season', 'episode'}.
+            tags: One of {country, director, genre, producer, actor, writer}.
+        """
+        args = {}
+        if title: args['title'] = title
+        if vtype: args['type'] = video.search_type(vtype)
+        for tag, obj in tags.iteritems():
+            args[tag] = obj.id
+        query = '/library/%s%s' % (filter, utils.joinArgs(args))
         return video.list_items(self.server, query)
 
     def cleanBundles(self):
@@ -126,10 +135,19 @@ class LibrarySection(object):
         path = '/library/sections/%s/all' % self.key
         return video.find_item(self.server, path, title)
 
-    def search(self, title, videotype=None, filter='all'):
-        title = urllib.quote(title)
-        query = '/library/sections/%s/%s?title=%s' % (self.key, filter, title)
-        if videotype: query += '&type=%s' % video.search_type(videotype)
+    def search(self, title, filter='all', vtype=None, **tags):
+        """ Search section content.
+            title: Title to search (pass None to search all titles).
+            filter: One of {'all', 'newest', 'onDeck', 'recentlyAdded', 'recentlyViewed', 'unwatched'}.
+            videotype: One of {'movie', 'show', 'season', 'episode'}.
+            tags: One of {country, director, genre, producer, actor, writer}.
+        """
+        args = {}
+        if title: args['title'] = title
+        if vtype: args['type'] = video.search_type(vtype)
+        for tag, obj in tags.iteritems():
+            args[tag] = obj.id
+        query = '/library/sections/%s/%s%s' % (self.key, filter, utils.joinArgs(args))
         return video.list_items(self.server, query)
 
     def analyze(self):
@@ -139,7 +157,7 @@ class LibrarySection(object):
         self.server.query('/library/sections/%s/emptyTrash' % self.key)
 
     def refresh(self):
-        self.server.query('/library/sections/%s/refresh' % self.key)    
+        self.server.query('/library/sections/%s/refresh' % self.key)
 
 
 class MovieSection(LibrarySection):
@@ -163,8 +181,8 @@ class MovieSection(LibrarySection):
     def resolution(self, input=None):
         return self._secondary_list('resolution', input)
 
-    def search(self, title, filter='all'):
-        return super(MovieSection, self).search(title, video.Movie.TYPE, filter)
+    def search(self, title, filter='all', **tags):
+        return super(MovieSection, self).search(title, filter=filter, vtype=video.Movie.TYPE, **tags)
 
 
 class ShowSection(LibrarySection):
@@ -173,11 +191,11 @@ class ShowSection(LibrarySection):
     def recentlyViewedShows(self):
         return self._primary_list('recentlyViewedShows')
 
-    def search(self, title, filter='all'):
-        return super(ShowSection, self).search(title, video.Show.TYPE, filter)
+    def search(self, title, filter='all', **tags):
+        return super(ShowSection, self).search(title, filter=filter, vtype=video.Show.TYPE, **tags)
 
-    def searchEpisodes(self, title, filter='all'):
-        return super(ShowSection, self).search(title, video.Episode.TYPE, filter)
+    def searchEpisodes(self, title, filter='all', **tags):
+        return super(ShowSection, self).search(title, filter=filter, vtype=video.Episode.TYPE, **tags)
 
 
 def list_choices(server, path):
