@@ -1,6 +1,7 @@
 """
 PlexVideo
 """
+from plexapi.media import Media, Country, Director, Genre, Producer, Actor, Writer
 from plexapi.exceptions import NotFound, UnknownType
 from plexapi.utils import PlexPartialObject, NA
 from plexapi.utils import cast, toDatetime
@@ -28,6 +29,20 @@ class Video(PlexPartialObject):
         self.addedAt = toDatetime(data.attrib.get('addedAt', NA))
         self.updatedAt = toDatetime(data.attrib.get('updatedAt', NA))
         self.lastViewedAt = toDatetime(data.attrib.get('lastViewedAt', NA))
+        if self.isFullObject():
+            # These are auto-populated when requested
+            self.media = [Media(self.server, elem, self.initpath, self) for elem in data if elem.tag == Media.TYPE]
+            self.countries = [Country(self.server, elem) for elem in data if elem.tag == Country.TYPE]
+            self.directors = [Director(self.server, elem) for elem in data if elem.tag == Director.TYPE]
+            self.genres = [Genre(self.server, elem) for elem in data if elem.tag == Genre.TYPE]
+            self.producers = [Producer(self.server, elem) for elem in data if elem.tag == Producer.TYPE]
+            self.actors = [Actor(self.server, elem) for elem in data if elem.tag == Actor.TYPE]
+            self.writers = [Writer(self.server, elem) for elem in data if elem.tag == Writer.TYPE]
+
+    def iter_parts(self):
+        for media in self.media:
+            for part in media.parts:
+                yield part
 
     def analyze(self):
         self.server.query('/%s/analyze' % self.key)
@@ -156,33 +171,6 @@ class Episode(Video):
         return list_items(self.server, self.grandparentKey)[0]
 
 
-class Media:
-    
-    def __init__(self, server, data):
-        self.videoResolution = self.data.attrib.get('videoResolution')
-        self.id = self.data.attrib.get('id')
-        self.duration = self.data.attrib.get('duration')
-        self.bitrate = self.data.attrib.get('bitrate')
-        self.width = self.data.attrib.get('width')
-        self.height = self.data.attrib.get('height')
-        self.aspectRatio = self.data.attrib.get('aspectRatio')
-        self.audioChannels = self.data.attrib.get('audioChannels')
-        self.audioCodec = self.data.attrib.get('audioCodec')
-        self.videoCodec = self.data.attrib.get('videoCodec')
-        self.container = self.data.attrib.get('container')
-        self.videoFrameRate = self.data.attrib.get('videoFrameRate')
-
-
-class MediaPart:
-
-    def __init__(self, server, data):
-        self.id = self.data.attrib.get('id')
-        self.key = self.data.attrib.get('key')
-        self.duration = self.data.attrib.get('duration')
-        self.file = self.data.attrib.get('file')
-        self.size = self.data.attrib.get('size')
-        self.container = self.data.attrib.get('container')
-
 
 def build_item(server, elem, initpath):
     VIDEOCLS = {Movie.TYPE:Movie, Show.TYPE:Show, Season.TYPE:Season, Episode.TYPE:Episode}
